==> mysql-8.0.26.tar.gz: mysql-8.0.26/storage/ndb/include/kernel/signaldata/IndxKeyInfo.hpp <==
/*
   Copyright (c) 2003, 2021, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef INDX_KEY_INFO_HPP
#define INDX_KEY_INFO_HPP

#include "SignalData.hpp"

#define JAM_FILE_ID 203


class IndxKeyInfo {
  /**
   * Sender(s)
   */
  friend class NdbIndexOperation;

  /**
   * Reciver(s)
   */
  friend class Dbtc;
  
  friend bool printINDXKEYINFO(FILE *, const Uint32 *, Uint32, Uint16);

public:
  static constexpr Uint32 HeaderLength = 3;
  static constexpr Uint32 DataLength = 20;
  static constexpr Uint32 MaxSignalLength = HeaderLength + DataLength;

  // Public methods
public:
 Uint32* getData() const;

private:
  Uint32 connectPtr;
  Uint32 transId[2];
  Uint32 keyData[DataLength];
};

inline
Uint32* IndxKeyInfo::getData() const
{
  return (Uint32*)&keyData[0];
}


#undef JAM_FILE_ID

#endif

==> mysql-8.0.32.tar.gz: mysql-8.0.32/storage/ndb/include/kernel/signaldata/IndxKeyInfo.hpp <==
/*
   Copyright (c) 2003, 2022, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef INDX_KEY_INFO_HPP
#define INDX_KEY_INFO_HPP

#include "SignalData.hpp"

#define JAM_FILE_ID 203


class IndxKeyInfo {
  /**
   * Sender(s)
   */
  friend class NdbIndexOperation;

  /**
   * Reciver(s)
   */
  friend class Dbtc;
  
  friend bool printINDXKEYINFO(FILE *, const Uint32 *, Uint32, Uint16);

public:
  static constexpr Uint32 HeaderLength = 3;
  static constexpr Uint32 DataLength = 20;
  static constexpr Uint32 MaxSignalLength = HeaderLength + DataLength;

  // Public methods
public:
 const Uint32* getData() const;

private:
  Uint32 connectPtr;
  Uint32 transId[2];
  Uint32 keyData[DataLength];
};

inline const Uint32* IndxKeyInfo::getData() const { return keyData; }

#undef JAM_FILE_ID

#endif
